==> kicad-9.0.1.tar.bz2: kicad-9.0.1/eeschema/dialogs/dialog_label_properties.h <==
/*
 * This program source code file is part of KiCad, a free EDA CAD application.
 *
 * Copyright The KiCad Developers, see AUTHORS.txt for contributors.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, you may find one here:
 * http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 * or you may search the http://www.gnu.org website for the version 2 license,
 * or you may write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

#ifndef DIALOG_LABEL_PROPERTIES_H
#define DIALOG_LABEL_PROPERTIES_H

#include <fields_grid_table.h>
#include <widgets/unit_binder.h>
#include <sch_validators.h>
#include <dialog_label_properties_base.h>


class SCH_EDIT_FRAME;
class HTML_MESSAGE_BOX;


class DIALOG_LABEL_PROPERTIES : public DIALOG_LABEL_PROPERTIES_BASE
{
public:
    DIALOG_LABEL_PROPERTIES( SCH_EDIT_FRAME* parent, SCH_LABEL_BASE* aLabel );
    ~DIALOG_LABEL_PROPERTIES();

    FIELDS_GRID_TABLE* GetFieldsGridTable() { return m_fields; }

private:
    /**
     * wxEVT_COMMAND_ENTER event handler for single-line control.
     */
    void OnEnterKey( wxCommandEvent& aEvent ) override;
    void OnValueCharHook( wxKeyEvent& aEvent ) override;
    void OnFormattingHelp( wxHyperlinkEvent& aEvent ) override;

    void onSpinButton( wxCommandEvent &aEvent );

    // event handlers
    void OnAddField( wxCommandEvent& event ) override;
    void OnDeleteField( wxCommandEvent& event ) override;
    void OnMoveUp( wxCommandEvent& event ) override;
    void OnMoveDown( wxCommandEvent& event ) override;
    void OnSizeGrid( wxSizeEvent& event ) override;
    void OnUpdateUI( wxUpdateUIEvent& event ) override;

    void AdjustGridColumns( int aWidth );

    bool TransferDataToWindow() override;
    bool TransferDataFromWindow() override;

private:
    SCH_EDIT_FRAME*       m_Parent;
    int                   m_width;
    int                   m_delayedFocusRow;
    int                   m_delayedFocusColumn;

    SCH_LABEL_BASE*       m_currentLabel;
    wxTextEntry*          m_activeTextEntry;
    SCH_NETNAME_VALIDATOR m_netNameValidator;

    FIELDS_GRID_TABLE*    m_fields;
    std::bitset<64>       m_shownColumns;

    UNIT_BINDER           m_textSize;

    HTML_MESSAGE_BOX*     m_helpWindow;
};


#endif // DIALOG_LABEL_PROPERTIES_H

==> kicad-9.0.2.tar.bz2: kicad-9.0.2/eeschema/dialogs/dialog_label_properties.h <==
/*
 * This program source code file is part of KiCad, a free EDA CAD application.
 *
 * Copyright The KiCad Developers, see AUTHORS.txt for contributors.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, you may find one here:
 * http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 * or you may search the http://www.gnu.org website for the version 2 license,
 * or you may write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

#ifndef DIALOG_LABEL_PROPERTIES_H
#define DIALOG_LABEL_PROPERTIES_H

#include <fields_grid_table.h>
#include <widgets/unit_binder.h>
#include <sch_validators.h>
#include <dialog_label_properties_base.h>


class SCH_EDIT_FRAME;
class HTML_MESSAGE_BOX;


class DIALOG_LABEL_PROPERTIES : public DIALOG_LABEL_PROPERTIES_BASE
{
public:
    DIALOG_LABEL_PROPERTIES( SCH_EDIT_FRAME* parent, SCH_LABEL_BASE* aLabel );
    ~DIALOG_LABEL_PROPERTIES();

    FIELDS_GRID_TABLE* GetFieldsGridTable() { return m_fields; }

private:
    /**
     * wxEVT_COMMAND_ENTER event handler for single-line control.
     */
    void OnEnterKey( wxCommandEvent& aEvent ) override;
    void OnValueCharHook( wxKeyEvent& aEvent ) override;
    void OnFormattingHelp( wxHyperlinkEvent& aEvent ) override;

    void onSpinButton( wxCommandEvent &aEvent );

    // event handlers
    void OnAddField( wxCommandEvent& event ) override;
    void OnDeleteField( wxCommandEvent& event ) override;
    void OnMoveUp( wxCommandEvent& event ) override;
    void OnMoveDown( wxCommandEvent& event ) override;
    void OnSizeGrid( wxSizeEvent& event ) override;
    void OnUpdateUI( wxUpdateUIEvent& event ) override;

    /**
     * Handles the filtering of items in the wxComboBox based on user input.
     *
     * This function is triggered by the wxEVT_TEXT event when the user modifies 
     * the text in the combo box. It filters the dropdown list to display only 
     * the items that match the input text.
     *
     * @param event The wxCommandEvent associated with the wxEVT_TEXT event.
     */
    void OnLabelFilter( wxCommandEvent& event );

    /**
     * Handles the selection of an item from the wxComboBox dropdown.
     *
     * This function is triggered by the wxEVT_COMBOBOX event when the user selects 
     * an item. It ensures that the selected value is correctly processed and 
     * prevents unnecessary re-filtering based on the selection.
     *
     * @param event The wxCommandEvent associated with the wxEVT_COMBOBOX event.
     */
    void OnLabelItemSelected( wxCommandEvent& event );
    
    void AdjustGridColumns( int aWidth );

    bool TransferDataToWindow() override;
    bool TransferDataFromWindow() override;

private:
    SCH_EDIT_FRAME*       m_Parent;
    int                   m_width;
    int                   m_delayedFocusRow;
    int                   m_delayedFocusColumn;

    SCH_LABEL_BASE*       m_currentLabel;
    wxTextEntry*          m_activeTextEntry;
    SCH_NETNAME_VALIDATOR m_netNameValidator;

    FIELDS_GRID_TABLE*    m_fields;
    std::bitset<64>       m_shownColumns;

    UNIT_BINDER           m_textSize;

    HTML_MESSAGE_BOX*     m_helpWindow;
    wxArrayString         m_existingLabelArray;
    // To store the previous value of the text typed in label combo
    wxString              m_previousLabelText; 
};


#endif // DIALOG_LABEL_PROPERTIES_H
